@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,16 +41,16 @@ class TestFullySpecifiedEnvironment(AdviserUnitTestCase):
         """Test registering this unit for adviser runs."""
         builder_context.should_receive("is_adviser_pipeline").and_return(True)
 
-        assert FullySpecifiedEnvironment.should_include(builder_context) == {}
+        assert list(FullySpecifiedEnvironment.should_include(builder_context)) == [{}]
 
         builder_context.add_unit(FullySpecifiedEnvironment())
 
-        assert FullySpecifiedEnvironment.should_include(builder_context) is None
+        assert list(FullySpecifiedEnvironment.should_include(builder_context)) == []
 
     def test_should_include_no_include(self, builder_context: PipelineBuilderContext) -> None:
         """Test not registering the pipeline unit."""
         builder_context.should_receive("is_adviser_pipeline").and_return(False)
-        assert FullySpecifiedEnvironment.should_include(builder_context) is None
+        assert list(FullySpecifiedEnvironment.should_include(builder_context)) == []
 
     def test_run(self, context: Context) -> None:
         """Test if the given software environment is fully specified."""
@@ -65,6 +65,11 @@ class TestFullySpecifiedEnvironment(AdviserUnitTestCase):
         context.project.runtime_environment.should_receive("is_fully_specified").and_return(False)
 
         unit = FullySpecifiedEnvironment()
+        assert not context.stack_info
+
         with pytest.raises(NotAcceptable):
             with unit.assigned_context(context):
                 unit.run()
+
+        assert len(context.stack_info) == 1
+        assert self.verify_justification_schema(context.stack_info)
