@@ -23,7 +23,7 @@ from typing import List
 from typing import Optional
 from typing import Union
 
-import flexmock
+from flexmock import flexmock
 import pytest
 
 from thoth.adviser.enums import RecommendationType
@@ -395,7 +395,7 @@ class TestUnitPrescription(AdviserTestCase):
             (
                 {"operating_systems": [{"name": "rhel"}]},
                 {"operating_system": {"name": "rhel", "version": "8"}},
-                False,
+                True,
             ),
             # CPU/GPU.
             (
