@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ class TestAliasPseudonym(AdviserUnitTestCase):
         builder_context.decision_type = None
         builder_context.recommendation_type = RecommendationType.STABLE
         assert builder_context.is_adviser_pipeline()
-        assert self.UNIT_TESTED.should_include(builder_context) is None
+        assert list(self.UNIT_TESTED.should_include(builder_context)) == []
 
     @pytest.mark.parametrize(
         "tf_version,index_url",
