@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,11 @@ from .unit import Unit
 class Sieve(Unit):
     """Sieve base class implementation."""
 
+    @staticmethod
+    def is_sieve_unit_type() -> bool:
+        """Check if this unit is of type sieve."""
+        return True
+
     @abc.abstractmethod
     def run(self, package_versions: Generator[PackageVersion, None, None]) -> Generator[PackageVersion, None, None]:
         """Run main entry-point for sieves to filter and score packages."""
