@@ -18,6 +18,7 @@
 """Implementation of sieves used in adviser pipeline."""
 
 from .constraints import ConstraintsSieve
+from .cve import CveSieve
 from .experimental_filter_conf_index import FilterConfiguredIndexSieve
 from .experimental_package_index import PackageIndexConfigurationSieve
 from .experimental_prereleases import SelectiveCutPreReleasesSieve
@@ -27,6 +28,8 @@ from .legacy_version import LegacyVersionSieve
 from .locked import CutLockedSieve
 from .package_combinations import PackageCombinationsSieve
 from .prereleases import CutPreReleasesSieve
+from ._pulp import NoPulpIndexLabelSieve
+from ._pulp import PulpIndexLabelSieve
 from .rules import SolverRulesSieve
 from .solved import SolvedSieve
 from .tensorflow import TensorFlowAPISieve
@@ -42,9 +45,12 @@ __all__ = [
     "PackageUpdateSieve",
     "LegacyVersionSieve",
     "CutPreReleasesSieve",
+    "PulpIndexLabelSieve",
+    "NoPulpIndexLabelSieve",
     "ConstraintsSieve",
     "SelectiveCutPreReleasesSieve",
     "FilterConfiguredIndexSieve",
+    "CveSieve",
     "PackageCombinationsSieve",
     "PackageIndexConfigurationSieve",
     "CutLockedSieve",
