@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,11 @@ from .unit import Unit
 class Stride(Unit):
     """Stride base class implementation."""
 
+    @staticmethod
+    def is_stride_unit_type() -> bool:
+        """Check if this unit is of type stride."""
+        return True
+
     @abc.abstractmethod
     def run(self, state: State) -> None:
         """Run main entry-point for strides."""
