@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ from typing import Any
 from typing import Dict
 from typing import Generator
 from typing import Optional
+from typing import Tuple
 from typing import Union
 from contextlib import contextmanager
 
@@ -35,6 +36,7 @@ from voluptuous import Any as SchemaAny
 from thoth.python import PackageVersion
 
 from .context import Context
+from .exceptions import ParseBaseImageError
 from .exceptions import PipelineUnitConfigurationSchemaError
 from .dm_report import DependencyMonkeyReport
 
@@ -52,14 +54,12 @@ _LOGGER = logging.getLogger(__name__)
 class Unit(metaclass=abc.ABCMeta):
     """A base class for implementing pipeline units - strides and steps."""
 
-    _configuration = attr.ib(type=Dict[str, Any], kw_only=True)
-    _name = attr.ib(type=str, default=None, kw_only=True)
-
     _CONTEXT: Optional[Context] = None
     CONFIGURATION_SCHEMA: Schema = Schema({Required("package_name"): SchemaAny(str, None)})
     CONFIGURATION_DEFAULT: Dict[str, Any] = {"package_name": None}
 
     unit_run = attr.ib(type=bool, default=False, kw_only=True)
+    _configuration = attr.ib(type=Dict[str, Any], kw_only=True)
 
     _RE_CAMEL2SNAKE = re.compile("(?!^)([A-Z]+)")
     _AICOE_PYTHON_PACKAGE_INDEX_URL = "https://tensorflow.pypi.thoth-station.ninja/index/"
@@ -67,10 +67,45 @@ class Unit(metaclass=abc.ABCMeta):
     _DATA_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data")
 
     @classmethod
-    def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
+    def get_unit_name(cls) -> str:
+        """Get name of the unit."""
+        return cls.__name__
+
+    @staticmethod
+    def is_boot_unit_type() -> bool:
+        """Check if the unit is of type boot."""
+        return False
+
+    @staticmethod
+    def is_pseudonym_unit_type() -> bool:
+        """Check if the unit is of type pseudonym."""
+        return False
+
+    @staticmethod
+    def is_sieve_unit_type() -> bool:
+        """Check if the unit is of type sieve."""
+        return False
+
+    @staticmethod
+    def is_step_unit_type() -> bool:
+        """Check if the unit is of type step."""
+        return False
+
+    @staticmethod
+    def is_stride_unit_type() -> bool:
+        """Check if the unit is of type step."""
+        return False
+
+    @staticmethod
+    def is_wrap_unit_type() -> bool:
+        """Check if the unit is of type wrap."""
+        return False
+
+    @classmethod
+    def should_include(cls, builder_context: "PipelineBuilderContext") -> Generator[Dict[str, Any], None, None]:
         """Check if the given pipeline unit should be included in the given pipeline configuration."""
         raise NotImplementedError(
-            f"Please implement method to register pipeline unit {cls.__name__!r} to pipeline configuration"
+            f"Please implement method to register pipeline unit {cls.get_unit_name()!r} to pipeline configuration"
         )
 
     @classmethod
@@ -83,16 +118,6 @@ class Unit(metaclass=abc.ABCMeta):
         finally:
             cls._CONTEXT = None
 
-    @classmethod
-    def compute_expanded_configuration(cls, configuration_dict: Optional[Dict[str, Any]]) -> Dict[str, Any]:
-        """Compute configuration as they would be computed based on unit configuration."""
-        result = dict(cls.CONFIGURATION_DEFAULT)
-
-        if configuration_dict:
-            result.update(configuration_dict)
-
-        return result
-
     def __attrs_post_init__(self) -> None:
         """Initialize post-init attributes."""
         # Initialize unit_run always to False so the pipeline unit JSON report can be reused across
@@ -136,13 +161,13 @@ class Unit(metaclass=abc.ABCMeta):
                 _LOGGER.exception(
                     "Failed to validate schema for pipeline unit %r: %s",
                     self.name,
-                    str(exc),
+                    exc,
                 )
                 raise PipelineUnitConfigurationSchemaError(str(exc))
 
     def to_dict(self) -> Dict[str, Any]:
-        """Turn this pipeline step into its dictionary representation."""
-        return {"name": self.__class__.__name__, "configuration": self.configuration, "unit_run": self.unit_run}
+        """Turn this pipeline unit into its dictionary representation."""
+        return {"name": self.name, "configuration": self.configuration, "unit_run": self.unit_run}
 
     @classmethod
     def is_aicoe_release(cls, package_version: PackageVersion) -> bool:
@@ -191,6 +216,27 @@ class Unit(metaclass=abc.ABCMeta):
         )
         return None
 
+    @staticmethod
+    def get_base_image(base_image: str, *, raise_on_error: bool = False) -> Optional[Tuple[str, str]]:
+        """Return information about base image used."""
+        parts = base_image.split(":", maxsplit=1)
+        if len(parts) != 2:
+            if raise_on_error:
+                raise ParseBaseImageError(
+                    f"Cannot determine Thoth s2i version information from {base_image}, "
+                    "recommendations specific for ABI used will not be taken into account"
+                )
+
+            return None
+
+        thoth_s2i_image_name, thoth_s2i_image_version = parts
+        if thoth_s2i_image_version.startswith("v"):
+            # Not nice as we always prefix with "v" but do not store it with "v" in the database
+            # (based on env var exported and detected in Thoth's s2i).
+            thoth_s2i_image_version = thoth_s2i_image_version[1:]
+
+        return thoth_s2i_image_name, thoth_s2i_image_version
+
     def pre_run(self) -> None:  # noqa: D401
         """Called before running any pipeline unit with context already assigned.
 
